@@ -1,3 +1,11 @@
+"use strict";
+
+var _doc_views = require("ui/registry/doc_views");
+
+var _i18n = require("@kbn/i18n");
+
+var _json_code_block = require("./json_code_block");
+
 /*
  * Licensed to Elasticsearch B.V. under one or more contributor
  * license agreements. See the NOTICE file distributed with
@@ -17,28 +25,14 @@
  * under the License.
  */
 
-import angular from 'angular';
-import 'ace';
-import { DocViewsRegistryProvider } from 'ui/registry/doc_views';
-
-import jsonHtml from './json.html';
-
-DocViewsRegistryProvider.register(function () {
-  return {
-    title: 'JSON',
-    order: 20,
-    directive: {
-      template: jsonHtml,
-      scope: {
-        hit: '='
-      },
-      controller: function ($scope) {
-        $scope.hitJson = angular.toJson($scope.hit, true);
-
-        $scope.aceLoaded = (editor) => {
-          editor.$blockScrolling = Infinity;
-        };
-      }
-    }
-  };
-});
+/*
+ * Registration of the the doc view: json
+ * - used to display an ES hit as pretty printed JSON at Discover
+ */
+(0, _doc_views.addDocView)({
+  title: _i18n.i18n.translate('kbnDocViews.json.jsonTitle', {
+    defaultMessage: 'JSON'
+  }),
+  order: 20,
+  component: _json_code_block.JsonCodeBlock
+});
\ No newline at end of file
