@@ -20,6 +20,8 @@
 import _ from 'lodash';
 import { uiModules } from 'ui/modules';
 import vislibValueAxesTemplate from './value_axes.html';
+import { safeMakeLabel } from 'ui/agg_types/agg_utils';
+
 const module = uiModules.get('kibana');
 
 module.directive('vislibValueAxes', function () {
@@ -193,7 +195,7 @@ module.directive('vislibValueAxes', function () {
 
       $scope.$watch(() => {
         return $scope.editorState.aggs.map(agg => {
-          return agg.makeLabel();
+          return safeMakeLabel(agg);
         }).join();
       }, () => {
         $scope.updateAxisTitle();
