@@ -17,7 +17,7 @@
  * under the License.
  */
 
-import basicAggs from '../../../../common/basic_aggs';
+import { basicAggs } from '../../../../common/basic_aggs';
 
 export function isSortable(metric) {
   return basicAggs.includes(metric.type);
