@@ -20,13 +20,16 @@
 import $ from 'jquery';
 import template from './tooltip.html';
 
-export const TileMapTooltipFormatter = ($compile, $rootScope) => {
+export const TileMapTooltipFormatter = ($injector) => {
+  const $rootScope = $injector.get('$rootScope');
+  const $compile = $injector.get('$compile');
+
   const $tooltipScope = $rootScope.$new();
   const $el = $('<div>').html(template);
+
   $compile($el)($tooltipScope);
 
   return function tooltipFormatter(metric, fieldFormatter, fieldName, metricName) {
-
     if (!metric) {
       return '';
     }
