@@ -20,7 +20,6 @@
 import { IndexedArray } from '../indexed_array';
 import { FieldParamType } from './param_types/field';
 import { OptionedParamType } from './param_types/optioned';
-import { SelectParamType } from './param_types/select';
 import { StringParamType } from './param_types/string';
 import { JsonParamType } from './param_types/json';
 import { BaseParamType } from './param_types/base';
@@ -28,9 +27,7 @@ import { createLegacyClass } from '../utils/legacy_class';
 
 const paramTypeMap = {
   field: FieldParamType,
-  // todo: remove select type and update optioned type after EUIfication of all components;
   optioned: (OptionedParamType),
-  select: SelectParamType,
   string: (StringParamType),
   json: (JsonParamType),
   _default: (BaseParamType)
